@@ -4,7 +4,8 @@
  *	pqxx/compiler.h
  *
  *   DESCRIPTION
- *      Compiler deficiency workarounds
+ *      Compiler deficiency workarounds for compiling libpqxx itself.
+ *      DO NOT INCLUDE THIS FILE when building client programs.
  *
  * Copyright (c) 2002-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
@@ -17,45 +18,9 @@
 #ifndef PQXX_COMPILER_H
 #define PQXX_COMPILER_H
 
+// Workarounds & definitions needed to compile libpqxx into a library
 #include "pqxx/config.h"
-
-#ifdef BROKEN_ITERATOR
-namespace PGSTD
-{
-/// Work around lacking iterator template definition in <iterator>
-template<typename Cat, 
-         typename T, 
-	 typename Dist, 
-	 typename Ptr=T*,
-	 typename Ref=T&> struct iterator
-{
-  typedef Cat iterator_category;
-  typedef T value_type;
-  typedef Dist difference_type;
-  typedef Ptr pointer;
-  typedef Ref reference;
-};
-}
-#else
-#include <iterator>
-#endif // BROKEN_ITERATOR
-
-#ifndef HAVE_CHAR_TRAITS
-namespace PGSTD
-{
-/// Work around missing std::char_traits
-template<typename CHAR> struct char_traits {};
-/// Work around missing std::char_traits<char>
-template<> struct char_traits<char>
-{
-  typedef int int_type;
-  typedef size_t pos_type;
-  typedef ptrdiff_t off_type;
-
-  static int_type eof() { return -1; }
-};
-}
-#endif
+#include "pqxx/libcompiler.h"
 
 
 #ifdef HAVE_LIMITS
@@ -84,10 +49,5 @@ template<> inline long numeric_limits<long>::min() throw () {return LONG_MIN;}
 long abs(long n) { return (n >= 0) ? n : -n; }
 #endif // HAVE_ABS_LONG
 
-// Used for Windows DLL
-#ifndef PQXX_LIBEXPORT
-#define PQXX_LIBEXPORT
-#endif
-
 #endif
 
