@@ -1,3 +1,5 @@
+#include <pqxx/compiler.h>
+
 #include <iostream>
 
 #include <pqxx/connection>
@@ -44,19 +46,18 @@ int main(int, char *argv[])
     // considerate and close the connection now.  This is optional.
     C.disconnect();
 
-#ifdef HAVE_PQFTABLE
+#ifdef PQXX_HAVE_PQFTABLE
     // Ah, this version of postgres will tell you which table a column in a
     // result came from.  Let's just test that functionality...
-    const string rtable = R.column_table(0);
+    const oid rtable = R.column_table(0);
     const string rcol = R.column_name(0);
 
-    if (rtable != Table)
-      throw logic_error("Field " + rcol + " comes from '" + rtable + "'; "
-	    		"expected '" + Table + "'");
-    const string crtable = R.column_table(rcol);
+    const oid crtable = R.column_table(rcol);
     if (crtable != rtable)
-      throw logic_error("Field " + rcol + " comes from '" + rtable + "', "
-	  		"but by name, result says it's from '" + crtable + "'");
+      throw logic_error("Field " + rcol + " comes from "
+                        "'" + ToString(rtable) + "', "
+	  		"but by name, result says it's from "
+                        "'" + ToString(crtable) + "'");
 #endif
 
     // Now we've got all that settled, let's process our results.
@@ -64,20 +65,22 @@ int main(int, char *argv[])
     {
       cout << '\t' << ToString(i) << '\t' << R[i][0].c_str() << endl;
 
-#ifdef HAVE_PQFTABLE
-      const string ftable = R[i][0].table();
+#ifdef PQXX_HAVE_PQFTABLE
+      const oid ftable = R[i][0].table();
       if (ftable != rtable)
-	throw logic_error("Field says it comes from '" + ftable + "'; "
-			  "expected '" + rtable + "'");
-      const string ttable = R[i].column_table(0);
+	throw logic_error("Field says it comes from "
+                          "'" + ToString(ftable) + "'; "
+			  "expected '" + ToString(rtable) + "'");
+      const oid ttable = R[i].column_table(0);
       if (ttable != rtable)
-	throw logic_error("Tuple says field comes from '" + ttable + "'; "
-	    		  "expected '" + rtable + "'");
-      const string cttable = R[i].column_table(rcol);
+	throw logic_error("Tuple says field comes from "
+                          "'" + ToString(ttable) + "'; "
+	    		  "expected '" + ToString(rtable) + "'");
+      const oid cttable = R[i].column_table(rcol);
       if (cttable != rtable)
-	throw logic_error("Field comes from '" + rtable + "', "
+	throw logic_error("Field comes from '" + ToString(rtable) + "', "
 	                  "but by name, tuple says it's from '" + 
-			  cttable + "'");
+			  ToString(cttable) + "'");
 #endif
     }
   }
