@@ -2,10 +2,10 @@
 #include <iostream>
 #include <vector>
 
-#include <pqxx/connection.h>
-#include <pqxx/tablewriter.h>
-#include <pqxx/transaction.h>
-#include <pqxx/result.h>
+#include <pqxx/connection>
+#include <pqxx/tablewriter>
+#include <pqxx/transaction>
+#include <pqxx/result>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -21,20 +21,20 @@ using namespace pqxx;
 // called template1, or "host=foo.bar.net user=smith" to connect to a
 // backend running on host foo.bar.net, logging in as user smith.
 //
-// The program will attempt to add an entry to a table called "events",
+// The program will attempt to add an entry to a table called "pqxxevents",
 // with a key column called "year"--and then abort the change.
 
 namespace
 {
 
-// Let's take a boring year that is not going to be in the "events" table
+// Let's take a boring year that is not going to be in the "pqxxevents" table
 const int BoringYear = 1977;
 
-const string Table = "events";
+const string Table = "pqxxevents";
 
 
 // Count events, and boring events, in table
-pair<int,int> CountEvents(Transaction &T)
+pair<int,int> CountEvents(transaction_base &T)
 {
   const string EventsQuery = "SELECT count(*) FROM " + Table;
   const string BoringQuery = EventsQuery + 
@@ -43,10 +43,10 @@ pair<int,int> CountEvents(Transaction &T)
   int EventsCount = 0,
       BoringCount = 0;
 
-  result R( T.Exec(EventsQuery) );
+  result R( T.exec(EventsQuery) );
   R.at(0).at(0).to(EventsCount);
 
-  R = T.Exec(BoringQuery);
+  R = T.exec(BoringQuery);
   R.at(0).at(0).to(BoringCount);
 
   return make_pair(EventsCount, BoringCount);
@@ -69,7 +69,7 @@ void Test(connection_base &C, bool ExplicitAbort)
   {
     // Begin a transaction acting on our current connection; we'll abort it
     // later though.
-    Transaction Doomed(C, "Doomed");
+    transaction<> Doomed(C, "Doomed");
 
     // Verify that our Boring Year was not yet in the events table
     EventCounts = CountEvents(Doomed);
@@ -84,11 +84,11 @@ void Test(connection_base &C, bool ExplicitAbort)
     {
       tablewriter W(Doomed, Table);
 
-      if (W.Name() != Table)
+      if (W.name() != Table)
         throw logic_error("Set tablewriter name to '" + Table + "', "
-                "but now it's '" + W.Name() + "'");
+                "but now it's '" + W.name() + "'");
 
-      const string Literal = W.ezinekoT(BoringTuple);
+      const string Literal = W.generate(BoringTuple);
       const string Expected = ToString(BoringYear) + "\t" + BoringTuple[1];
       if (Literal != Expected)
 	throw logic_error("tablewriter writes new tuple as '" +
@@ -116,7 +116,7 @@ void Test(connection_base &C, bool ExplicitAbort)
 
     // Okay, we've added an entry but we don't really want to.  Abort it
     // explicitly if requested, or simply let the Transaction object "expire."
-    if (ExplicitAbort) Doomed.Abort();
+    if (ExplicitAbort) Doomed.abort();
 
     // If now explicit abort requested, Doomed Transaction still ends here
   }
@@ -124,7 +124,7 @@ void Test(connection_base &C, bool ExplicitAbort)
   // Now check that we're back in the original state.  Note that this may go
   // wrong if somebody managed to change the table between our two 
   // transactions.
-  Transaction Checkup(C, "Checkup");
+  transaction<> Checkup(C, "Checkup");
 
   const pair<int,int> NewEvents = CountEvents(Checkup);
   if (NewEvents.first != EventCounts.first)
