@@ -1,8 +1,8 @@
 #include <iostream>
 
-#include <pqxx/connection.h>
-#include <pqxx/robusttransaction.h>
-#include <pqxx/result.h>
+#include <pqxx/connection>
+#include <pqxx/robusttransaction>
+#include <pqxx/result>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -27,9 +27,9 @@ int main(int, char *argv[])
     // Begin a "non-transaction" acting on our current connection.  This is
     // really all the transactional integrity we need since we're only 
     // performing one query which does not modify the database.
-    RobustTransaction T(C, "test35");
+    robusttransaction<> T(C, "test35");
 
-    result R( T.Exec("SELECT * FROM pg_tables") );
+    result R( T.exec("SELECT * FROM pg_tables") );
 
     for (result::const_iterator c = R.begin(); c != R.end(); ++c)
     {
@@ -41,7 +41,7 @@ int main(int, char *argv[])
 
     // "Commit" the non-transaction.  This doesn't really do anything since
     // NonTransaction doesn't start a backend transaction.
-    T.Commit();
+    T.commit();
   }
   catch (const sql_error &e)
   {
