@@ -1,9 +1,9 @@
 #include <cassert>
 #include <iostream>
 
-#include <pqxx/connection.h>
-#include <pqxx/nontransaction.h>
-#include <pqxx/result.h>
+#include <pqxx/connection>
+#include <pqxx/nontransaction>
+#include <pqxx/result>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -20,7 +20,8 @@ using namespace pqxx;
 // called template1, or "host=foo.bar.net user=smith" to connect to a
 // backend running on host foo.bar.net, logging in as user smith.
 //
-// The table argument is the table being modified.  This defaults to "events".
+// The table argument is the table being modified.  This defaults to 
+// "pqxxevents".
 // It is assumed to consist of an integer key called year, and a string.
 namespace
 {
@@ -34,14 +35,13 @@ int main(int argc, char *argv[])
   {
     lazyconnection C(argv[1]);
 
-    const string Table = ((argc > 2) ? argv[2] : "events");
+    const string Table = ((argc > 2) ? argv[2] : "pqxxevents");
 
-    // Begin a transaction acting on our current connection
-    NonTransaction T1(C, "T1");
+    nontransaction T1(C, "T1");
 
     // Verify our start condition before beginning: there must not be a 1977
     // record already.
-    result R( T1.Exec("SELECT * FROM " + Table + " "
+    result R( T1.exec("SELECT * FROM " + Table + " "
 	              "WHERE year=" + ToString(BoringYear)) );
     if (R.size() != 0)
       throw runtime_error("There is already a record for " + 
@@ -54,7 +54,7 @@ int main(int argc, char *argv[])
       throw logic_error("Result non-empty after clear()!");
 
     // OK.  Having laid that worry to rest, add a record for 1977.
-    T1.Exec("INSERT INTO " + Table + " VALUES"
+    T1.exec("INSERT INTO " + Table + " VALUES"
             "(" +
 	    ToString(BoringYear) + ","
 	    "'Yawn'"
@@ -63,11 +63,11 @@ int main(int argc, char *argv[])
     // Abort T1.  Since T1 is a NonTransaction, which provides only the
     // transaction class interface without providing any form of transactional
     // integrity, this is not going to undo our work.
-    T1.Abort();
+    T1.abort();
 
     // Verify that our record was added, despite the Abort()
-    NonTransaction T2(C, "T2");
-    R = T2.Exec("SELECT * FROM " + Table + " "
+    nontransaction T2(C, "T2");
+    R = T2.exec("SELECT * FROM " + Table + " "
 		"WHERE year=" + ToString(BoringYear));
     if (R.size() != 1)
       throw runtime_error("Expected to find 1 record for " + 
@@ -84,15 +84,15 @@ int main(int argc, char *argv[])
       throw logic_error("result::clear() doesn't work!");
 
     // Now remove our record again
-    T2.Exec("DELETE FROM " + Table + " "
+    T2.exec("DELETE FROM " + Table + " "
 	    "WHERE year=" + ToString(BoringYear));
 
-    T2.Commit();
+    T2.commit();
 
     // And again, verify results
-    NonTransaction T3(C, "T3");
+    nontransaction T3(C, "T3");
 
-    R = T3.Exec("SELECT * FROM " + Table + " "
+    R = T3.exec("SELECT * FROM " + Table + " "
 	        "WHERE year=" + ToString(BoringYear));
     if (R.size() != 0)
       throw runtime_error("Expected record for " + ToString(BoringYear) + " "
